@@ -2,13 +2,10 @@
 #define MATRIX_SSCLME_H
 
 #include "sscCrosstab.h"
-#include "ldl.h"
-#include "Metis_utils.h"
 #include <R_ext/Lapack.h>
 #include <R_ext/Constants.h>
 
-SEXP ctab_permute(SEXP ctab);
-SEXP ssclme_create(SEXP facs, SEXP ncv, SEXP threshhold);
+SEXP ssclme_create(SEXP facs, SEXP ncv);
 SEXP ssclme_transfer_dimnames(SEXP x, SEXP facs, SEXP mmats);
 SEXP ssclme_update_mm(SEXP x, SEXP facs, SEXP mmats);
 SEXP ssclme_inflate_and_factor(SEXP x);
@@ -23,7 +20,7 @@ SEXP ssclme_coefUnc(SEXP x);
 SEXP ssclme_coefGetsUnc(SEXP x, SEXP coef);
 SEXP ssclme_coefGets(SEXP x, SEXP coef);
 SEXP ssclme_EMsteps(SEXP x, SEXP nsteps, SEXP REMLp, SEXP verb);
-SEXP ssclme_fitted(SEXP x, SEXP facs, SEXP mmats);
+SEXP ssclme_fitted(SEXP x, SEXP facs, SEXP mmats, SEXP useRf);
 SEXP ssclme_variances(SEXP x);
 SEXP ssclme_gradient(SEXP x, SEXP REMLp, SEXP Uncp);
 SEXP ssclme_collapse(SEXP x);
